#!/home/ktietz/ci_310/gdal_1646324597832/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/python
# EASY-INSTALL-SCRIPT: 'GDAL==3.4.1','gdal2tiles.py'
__requires__ = 'GDAL==3.4.1'
__import__('pkg_resources').run_script('GDAL==3.4.1', 'gdal2tiles.py')



#!/home/ktietz/ci_310/gdal_1646324597832/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/python

import sys
# import osgeo_utils.gdal_sieve as a convenience to use as a script
from osgeo_utils.gdal_sieve import *  # noqa
from osgeo_utils.gdal_sieve import main
from osgeo.gdal import deprecation_warn


deprecation_warn('gdal_sieve')
sys.exit(main(sys.argv))
